==> Evergreen-ILS-3.15.9.tar.gz: Evergreen-ILS-3.15.9/Open-ILS/web/js/dojo/openils/acq/nls/es-es/acq.js <==
{
    ":CREATE_PO_ASSETS_CONFIRM": "Esto creara un bibliogr\u00e1fico, un numero de llamada, y una copia del registro de esta compra en ILS.\n\nContinuar?",
    ":ROLLBACK_PO_RECEIVE_CONFIRM": "Esto reversionara el recibo de todas las copias para esta orden de compra.\n\nContinuar?",
    ":ROLLBACK_LI_RECEIVE_CONFIRM": "Esto deshacera recibo de los items seleccionados de esta orden de compra.\nContinuar?",
    ":XUL_RECORD_DETAIL_PAGE": "Detalles del Registro",
    ":DELETE_LI_COPIES_CONFIRM": "Esto borrara las \u00faltimas ${0} copias en la tabla.\u00bfContinuar?",
    ":NO_PO_RESULTS": "No hay resultados",
    ":PO_HEADING_ERROR": "Problema inesperado creando el PO combinado virtual",
    ":CONFIRM_SPLIT_PO": "\u00bfEst\u00e1s seguro de que desea separar la orden de compra entre\nuna orden de compra por cada art\u00edculo de l\u00ednea constituyente?",
    ":DFA_NOT_ALL": "No se pudo grabar toda su solicitud de formulas para distribuci\u00f3n",
    ":APPLY": "Aplicar",
    ":RESET_FORMULAE": "Restablecer f\u00f3rmulas",
    ":OUT_OF_COPIES": "Ha aplicado f\u00f3rmulas de distribuci\u00f3n ha cada copia.",
    ":ONE_LI_ATTR_SEARCH_AT_A_TIME": "No puede escribir una busqueda por un valor de atributo y una busqueda por un archivo subido de t\u00e9rminos a la misma vez.",
    ":LI_ATTR_SEARCH_CHOOSE_FILE": "Eliga archivo con los terminos de busqueda",
    ":LI_ATTR_SEARCH_TOO_LARGE": "Ese archivo es muy grande para esta operaci\u00f3n.",
    ":SELECT_AN_LI_ATTRIBUTE": "Debe seleccionar un atributo LI.",
    ":NO_RESULTS": "No hay resultados.",
    ":EXPORT_SAVE_DIALOG_TITLE": "Guardar las casillas a un archivo",
    ":EXPORT_SHORT_LIST": "No todos los art\u00edculos seleccionados tienen el atributo '${0}'.\nEliga aceptar para grabar esos valores que no fueron encontrados.",
    ":EXPORT_EMPTY_LIST": "Ningun valor para el atributo '${0}' encontrado.",
    ":UNRECEIVE_LI": "\u00bfEst\u00e1s seguro de que desea marcar este art\u00edculo de l\u00ednea como no recibido?",
    ":UNRECEIVE_LID": "\u00bfEst\u00e1s seguro de que desea marcar esta copia como no recebida?",
    ":CONFIRM_LI_ALERT": "Una alerta ha sido puesta en el lineitem titulado,\n\"${0}\":\n\n${1}\n${2}\n${3}\nEliga aceptar si desea reconocer esta alerta.",
    ":ALERT_UNSELECTED": "Debe de eligir un c\u00f3digo de alerta",
    ":DFA_TIP": "<strong>Aplicado por</strong>: ${0}<br /><strong>Cuando</strong>: ${1}",
    ":ITS_YOU": "Usted",
    ":JUST_NOW": "Ahora mismo",
    ":EXPLAIN_DFA_MGMT": "\u00bfRemover registro del uso de esta f\u00f3rmula de distribuci\u00f3n?",
    ":VENDOR_PUBLIC": "VENDEDOR P\u00daBLICO",
    ":PO_CANCEL_CONFIRM": "\u00bfEst\u00e1s SEGURO de que desea cancelar su orden de compra?",
    ":LI_CANCEL_CONFIRM": "\u00bfEst\u00e1s SEGURO de que desea cancelar este art\u00edculo de l\u00ednea?",
    ":LID_CANCEL_CONFIRM": "\u00bfEst\u00e1s seguro de que desea cancelar esta copia?",
    ":UR_CANCEL_CONFIRM": "\u00bfEst\u00e1s SEGURO de que desea cancelar este pedido del usuario?",
    ":UR_FILTER_USER": "Introduce el c\u00f3digo de barras para el usuario (o dejar en blanco para desarmar el filtro) :",
    ":UR_FILTER_LINEITEM": "Introduzca el ID de l\u00ednea de pedido (o dejar en blanco para desarmar el filtro)",
    ":CANCEL_REASON": "Raz\u00f3n para cancelar",
    ":CANCEL": "Cancelar",
    ":YES": "S\u00ed",
    ":NO": "No",
    ":VENDOR_SAYS_PREPAY_NOT_NEEDED": "El vendedor seleccionado no necesariamente requiere pago por adelantado, de acuerdo\ncon nuestros registros. \u00bfRequiere pago por adelantado en este PO siempre?",
    ":VENDOR_SAYS_PREPAY_NEEDED": "El vendedor seleccionado requiere pago por adelantado, de acuerdo a nuestros registros.\n\u00bfContinuar sin el pago por adelantado requerido en este PO?",
    ":PREPAYMENT_REQUIRED_REMINDER": "Este PO requiere pago por adelantado.\u00bfEst\u00e1s seguro de que esta listo para activarlo?",
    ":LI_FORMAT_ERROR": "Error inesperado recuperando la informaci\u00f3n formato lineitem.",
    ":FUND_NOT_YET_LOADED": "Fondo todav\u00eda no cargado. Intente regresando a esta pantalla m\u00e1s tarde.",
    ":CONFIRM_DELETE_MAPPING": "\u00bfEst\u00e1s seguro de que desea remover la etiqueta de este fondo?",
    ":COULD_NOT_CREATE_MAPPING": "Error etiquetando el fondo.",
    ":COULD_NOT_DELETE_MAPPING": "Error removiendo la etiqueta del fondo.",
    ":FUND_LIST_ROLLOVER_SUMMARY": "Propagaci\u00f3n del Fondo &amp; Resumen del a\u00f1o fiscal ${0}",
    ":FUND_LIST_ROLLOVER_SUMMARY_FUNDS": "${1} propagadas fondos para el a\u00f1o fiscal ${0} para las ubicaciones seleccionadas",
    ":FUND_LIST_ROLLOVER_SUMMARY_ROLLOVER_AMOUNT": "<b>$${1}</b> dinero no gastado fue pasado al a\u00f1o fiscal ${0} para los lugares seleccionados",
    ":FUND_XFER_SAME_SOURCE_AND_DEST": "No se puede transferir. Los fondos de origen y de destino son el mismo.",
    ":FUND_XFER_CONFIRM": "\u00bfEst\u00e1s seguro que esta listo para cometer esta transferencia?",
    ":PO_ACTIVATED_ON": "Activado ${0}",
    ":PO_CHECKING": "[Un momento...]",
    ":PO_COULD_ACTIVATE": "S\u00ed.",
    ":PO_WARNING_NO_BLOCK_ACTIVATION": "S\u00ed; fondo ${0} (${1}) ser\u00eda sobrecargado m\u00e1s all\u00e1 de su nivel de alerta.",
    ":PO_STOP_BLOCKS_ACTIVATION": "No; fondo ${0} (${1}) ser\u00eda sobrecardago m\u00e1s all\u00e1 de su nivel de parada.",
    ":PO_ALREADY_ACTIVATED": "Activado",
    ":PO_FUND_WARNING_CONFIRM": "\u00bfEst\u00e1s seguro?\u00bfVieno la alerta sobre sobrecargar su fondo?",
    ":CONFIRM_FUNDS_AT_STOP": "Uno o m\u00e1s de sus fondos seleccionados tiene un balance por debajo se su nivel de parada.\nPuede que usted no pueda activar ordenes de compra incorporando estas copias.\nContinuar?",
    ":CONFIRM_FUNDS_AT_WARNING": "Uno o m\u00e1s de sus fondos seleccionados tiene un balance por debajo de su nivel de alerta.\nContinuar?",
    ":INVOICE_ITEM_DETAILS": "${0} <br/> ${1} <br/> ${2}. <br/> Precio Estimado: $${3}. <br/> Identificaci\u00f3n del art\u00edculo de l\u00ednea: ${4} <br/> PO: ${5} <br/> Fecha de la orden: ${6}",
    ":INVOICE_CONFIRM_ITEM_DELETE": "\u00bfRemover este $${0} '${1}' cargo de la factura?",
    ":INVOICE_CONFIRM_ENTRY_DETACH": "\u00bfRemover $${0} cargo por el art\u00edculo ${1}, ${2} [${3}] de la factura?",
    ":LINEITEM_SUMMARY": "<div class='acq-lineitem-summary'><a target='_top' href='${19}'>${0}</a>, by ${1} (${2})</div>\n<div class='acq-lineitem-summary-extra'>\n${3} Ordered, ${4} Received, ${7} Invoiced, ${8} Claimed, ${9} Cancelled, ${23} Delayed</div>\n<div class='acq-lineitem-summary-extra'>Estimated $${6}, Encumbered $${16}, Paid $${17}</div>\n<div class='acq-lineitem-summary-extra'>\n# ${10} <a style='padding-right: 10px;' class='hidden${20}'  target='_top' href='/eg2/en-US/staff/acq/po/${12}#${10}'>&#x2318; ${13} ${18}</a>\n<a style='padding-right: 10px;' class='hidden${21}' target='_top' href='/eg2/en-US/staff/acq/picklist/${14}#${10}'>&#x2756; ${15}</a></div>",
    ":INVOICE_CONFIRM_PRORATE": "\u00bfProrratear cambions?\n\nCualquier cambio subsiguiente a la factura que afectar\u00eda la cantidad prorrateada debe ser resuelta manualmente.",
    ":INVOICE_EXTRA_COPIES": "Esta intentando de hacer una factura <b>${0}</b> mas copias que originalmente ordenadas. <br/><br/> Para agregar estos art\u00edculos a su orden, seleccione un fondo y eliga 'Agregar Nuevos Art\u00edculos' debajo. <br/>Despu\u00e9s de guardar su factura, puede terminar de editar y importar las copias nuevas de la pagina de detalles en lineitem",
    ":INVOICE_ITEM_PO_DETAILS": "<b>${0}</b><br/><a target='_top' href='/eg2/en-US/staff/acq/po/${2}'>PO #${3} ${4}</a><br/>Total Estimated Cost: $${5}",
    ":INVOICE_ITEM_PO_LABEL": "<a target='_top' href='/eg2/en-US/staff/acq/po/${1}'>PO #${2} ${3}</a><br/>Total Estimated Cost: $${4}",
    ":UNNAMED": "Sin nombre",
    ":NO_FIND_INVOICE": "No se pudo encontrar la factura.",
    ":LI_BATCH_UPDATE": "actualizaci\u00f3n de posici\u00f3n de lote line",
    ":NO_LI_TO_UPDATE": "No ha seleccionado ning\u00fan art\u00edculo en l\u00ednea para actualizar .",
    ":NO_LI_TO_CLAIM": "Usted no ha seleccionado ning\u00fan \u00edtem para reclamar",
    ":NO_LID_TO_CLAIM": "usted no ha seleccionado ning\u00fan detalles de la l\u00ednea con la reivindicaci\u00f3n",
    ":CHANGE_CLAIM_POLICY": "Cambiar la forma de petici\u00f3n",
    ":CANCELED": "Cancelado",
    ":RECVD": "Recibido",
    ":NOT_RECVD": "No fue recibido",
    ":PRINT": "Imprimir",
    ":INVOICES": "Facturas",
    ":NUM_CLAIMS_EXISTING": "Reclamaciones (${0} existentes)",
    ":LOAD_TERMS_FIRST": "No puede recuperar registros hasta que alla cargado un archivo CSV\ncon identificaci\u00f3n bibliogr\u00e1fico en la primera columna.",
    ":SELECT_SEARCH_FIELD": "Eliga Campo de Busqueda",
    ":LIBRARY_INITIATED": "Librer\u00eda Iniciada",
    ":DEL_LI_FROM_PO": "Ya se orden\u00f3 el \u00edtem seleccionado! El borrarlo ahora no cancelar\u00e1 ni modificar\u00e1 cualquier pedido que haya sido realizado a un proveedor. El borrar el \u00edtem puede provocar una idea incorrecta del estado de la orden de compra en el sistema lo que es una inconsistencia con la realidad. Est\u00e1 seguro que quiere realizar esto?",
    ":ADD_LI_TO_PO_BAD_PO_STATE": "La OC seleccionada ha sido previamente activada",
    ":ADD_LI_TO_PO_BAD_LI_STATE": "El \u00edtem seleccionado est\u00e1 en un estado que no permite ser a\u00f1adido a una orden de compra",
    ":INVOICE_NUMBER": "Factura #$(0)",
    ":COPIES_TO_RECEIVE": "Numero de copias a recibir: ",
    ":CREATE_PO_INVALID": "Una orden de compra debe tener una agencia solicitante y un proveedor.",
    ":INVOICE_COPY_COUNT_INFO": "Copias recibidas en esta factura: ${0} de ${1}.",
    ":INVOICE_IDENT_COLLIDE": "Ya existe una factura en el sistema con la combinaci\u00f3n ofrecida para'N\u00ba de factura' y 'Proveedor', lo cual no se permite",
    ":NEW_INVOICE": "Nueva factura",
    ":ACQ_SEARCH_CLASS_ABBR_jub": "Ll",
    ":ACQ_SEARCH_CLASS_ABBR_acqpl": "SL",
    ":ACQ_SEARCH_CLASS_ABBR_acqpo": "OC",
    ":ACQ_SEARCH_CLASS_ABBR_acqinv": "I",
    ":ACQ_SEARCH_CLASS_ABBR_acqlid": "LID",
    ":ACQ_SEARCH_CLASS_ABBR_acqlia": "LIA",
    ":NO_LI_GENERAL": "No ha seleccionado ning\u00fan art\u00edculo en l\u00ednea ( adecuado) .",
    ":DUPE_PO_NAME_MSG": "Este nombre ya est\u00e1 en uso por otro correo",
    ":DUPE_PO_NAME_LINK": "Ver PO",
    ":PO_NAME_OPTIONAL": "${0} (optional)",
    ":FINALIZE_PO": "Finalizar este correo general?\n\nEsto facilitara todos los cargos generales y marcara el correo como recibido.",
    ":LI_EXISTING_COPIES": "Hay ${ 0 } copias existentes para este registro bibliogr\u00e1fico en esta ubicaci\u00f3n",
    ":LI_CREATING_ASSETS": "Creando bib, numero de llamada, y copiar archivos...",
    ":PO_ACTIVATING": "Activando orden de compra...",
    ":ACTIVATE_LI_PROCESSED": "Articulos de linea procesado: ${0}",
    ":ACTIVATE_VQBR_PROCESSED": "Vandelay Registros Procesados: ${0}",
    ":ACTIVATE_BIBS_PROCESSED": "Archivos Bib Fusionado/Importado: ${0}",
    ":ACTIVATE_LID_PROCESSED": "ACQ Copias Procesadas: ${0}",
    ":ACTIVATE_DEBITS_ACCRUED_PROCESSED": "D\u00e9bitos Gravados: ${0}",
    ":ACTIVATE_COPIES_PROCESSED": "copias reales procesados: ${0}"
}

==> Evergreen-ILS-3.16.1.tar.gz: Evergreen-ILS-3.16.1/Open-ILS/web/js/dojo/openils/acq/nls/es-es/acq.js <==
{
    ":CREATE_PO_ASSETS_CONFIRM": "Esto creara un bibliogr\u00e1fico, un numero de llamada, y una copia del registro de esta compra en ILS.\n\nContinuar?",
    ":ROLLBACK_PO_RECEIVE_CONFIRM": "Esto reversionara el recibo de todas las copias para esta orden de compra.\n\nContinuar?",
    ":ROLLBACK_LI_RECEIVE_CONFIRM": "Esto deshacera recibo de los items seleccionados de esta orden de compra.\nContinuar?",
    ":XUL_RECORD_DETAIL_PAGE": "Detalles del Registro",
    ":DELETE_LI_COPIES_CONFIRM": "Esto borrara las \u00faltimas ${0} copias en la tabla.\u00bfContinuar?",
    ":NO_PO_RESULTS": "No hay resultados",
    ":PO_HEADING_ERROR": "Problema inesperado creando el PO combinado virtual",
    ":CONFIRM_SPLIT_PO": "\u00bfEst\u00e1s seguro de que desea separar la orden de compra entre\nuna orden de compra por cada art\u00edculo de l\u00ednea constituyente?",
    ":DFA_NOT_ALL": "No se pudo grabar toda su solicitud de formulas para distribuci\u00f3n",
    ":APPLY": "Aplicar",
    ":RESET_FORMULAE": "Restablecer f\u00f3rmulas",
    ":OUT_OF_COPIES": "Ha aplicado f\u00f3rmulas de distribuci\u00f3n ha cada copia.",
    ":ONE_LI_ATTR_SEARCH_AT_A_TIME": "No puede escribir una busqueda por un valor de atributo y una busqueda por un archivo subido de t\u00e9rminos a la misma vez.",
    ":LI_ATTR_SEARCH_CHOOSE_FILE": "Eliga archivo con los terminos de busqueda",
    ":LI_ATTR_SEARCH_TOO_LARGE": "Ese archivo es muy grande para esta operaci\u00f3n.",
    ":SELECT_AN_LI_ATTRIBUTE": "Debe seleccionar un atributo LI.",
    ":NO_RESULTS": "No hay resultados.",
    ":EXPORT_SAVE_DIALOG_TITLE": "Guardar las casillas a un archivo",
    ":EXPORT_SHORT_LIST": "No todos los art\u00edculos seleccionados tienen el atributo '${0}'.\nEliga aceptar para grabar esos valores que no fueron encontrados.",
    ":EXPORT_EMPTY_LIST": "Ningun valor para el atributo '${0}' encontrado.",
    ":UNRECEIVE_LI": "\u00bfEst\u00e1s seguro de que desea marcar este art\u00edculo de l\u00ednea como no recibido?",
    ":UNRECEIVE_LID": "\u00bfEst\u00e1s seguro de que desea marcar esta copia como no recebida?",
    ":CONFIRM_LI_ALERT": "Una alerta ha sido puesta en el lineitem titulado,\n\"${0}\":\n\n${1}\n${2}\n${3}\nEliga aceptar si desea reconocer esta alerta.",
    ":ALERT_UNSELECTED": "Debe de eligir un c\u00f3digo de alerta",
    ":DFA_TIP": "<strong>Aplicado por</strong>: ${0}<br /><strong>Cuando</strong>: ${1}",
    ":ITS_YOU": "Usted",
    ":JUST_NOW": "Ahora mismo",
    ":EXPLAIN_DFA_MGMT": "\u00bfRemover registro del uso de esta f\u00f3rmula de distribuci\u00f3n?",
    ":VENDOR_PUBLIC": "VENDEDOR P\u00daBLICO",
    ":PO_CANCEL_CONFIRM": "\u00bfEst\u00e1s SEGURO de que desea cancelar su orden de compra?",
    ":LI_CANCEL_CONFIRM": "\u00bfEst\u00e1s SEGURO de que desea cancelar este art\u00edculo de l\u00ednea?",
    ":LID_CANCEL_CONFIRM": "\u00bfEst\u00e1s seguro de que desea cancelar esta copia?",
    ":UR_CANCEL_CONFIRM": "\u00bfEst\u00e1s SEGURO de que desea cancelar este pedido del usuario?",
    ":UR_FILTER_USER": "Introduce el c\u00f3digo de barras para el usuario (o dejar en blanco para desarmar el filtro) :",
    ":UR_FILTER_LINEITEM": "Introduzca el ID de l\u00ednea de pedido (o dejar en blanco para desarmar el filtro)",
    ":CANCEL_REASON": "Raz\u00f3n para cancelar",
    ":CANCEL": "Cancelar",
    ":YES": "S\u00ed",
    ":NO": "No",
    ":VENDOR_SAYS_PREPAY_NOT_NEEDED": "El vendedor seleccionado no necesariamente requiere pago por adelantado, de acuerdo\ncon nuestros registros. \u00bfRequiere pago por adelantado en este PO siempre?",
    ":VENDOR_SAYS_PREPAY_NEEDED": "El vendedor seleccionado requiere pago por adelantado, de acuerdo a nuestros registros.\n\u00bfContinuar sin el pago por adelantado requerido en este PO?",
    ":PREPAYMENT_REQUIRED_REMINDER": "Este PO requiere pago por adelantado.\u00bfEst\u00e1s seguro de que esta listo para activarlo?",
    ":LI_FORMAT_ERROR": "Error inesperado recuperando la informaci\u00f3n formato lineitem.",
    ":FUND_NOT_YET_LOADED": "Fondo todav\u00eda no cargado. Intente regresando a esta pantalla m\u00e1s tarde.",
    ":CONFIRM_DELETE_MAPPING": "\u00bfEst\u00e1s seguro de que desea remover la etiqueta de este fondo?",
    ":COULD_NOT_CREATE_MAPPING": "Error etiquetando el fondo.",
    ":COULD_NOT_DELETE_MAPPING": "Error removiendo la etiqueta del fondo.",
    ":FUND_LIST_ROLLOVER_SUMMARY": "Propagaci\u00f3n del Fondo &amp; Resumen del a\u00f1o fiscal ${0}",
    ":FUND_LIST_ROLLOVER_SUMMARY_FUNDS": "${1} propagadas fondos para el a\u00f1o fiscal ${0} para las ubicaciones seleccionadas",
    ":FUND_LIST_ROLLOVER_SUMMARY_ROLLOVER_AMOUNT": "<b>$${1}</b> dinero no gastado fue pasado al a\u00f1o fiscal ${0} para los lugares seleccionados",
    ":FUND_XFER_SAME_SOURCE_AND_DEST": "No se puede transferir. Los fondos de origen y de destino son el mismo.",
    ":FUND_XFER_CONFIRM": "\u00bfEst\u00e1s seguro que esta listo para cometer esta transferencia?",
    ":PO_ACTIVATED_ON": "Activado ${0}",
    ":PO_CHECKING": "[Un momento...]",
    ":PO_COULD_ACTIVATE": "S\u00ed.",
    ":PO_WARNING_NO_BLOCK_ACTIVATION": "S\u00ed; fondo ${0} (${1}) ser\u00eda sobrecargado m\u00e1s all\u00e1 de su nivel de alerta.",
    ":PO_STOP_BLOCKS_ACTIVATION": "No; fondo ${0} (${1}) ser\u00eda sobrecardago m\u00e1s all\u00e1 de su nivel de parada.",
    ":PO_ALREADY_ACTIVATED": "Activado",
    ":PO_FUND_WARNING_CONFIRM": "\u00bfEst\u00e1s seguro?\u00bfVieno la alerta sobre sobrecargar su fondo?",
    ":CONFIRM_FUNDS_AT_STOP": "Uno o m\u00e1s de sus fondos seleccionados tiene un balance por debajo se su nivel de parada.\nPuede que usted no pueda activar ordenes de compra incorporando estas copias.\nContinuar?",
    ":CONFIRM_FUNDS_AT_WARNING": "Uno o m\u00e1s de sus fondos seleccionados tiene un balance por debajo de su nivel de alerta.\nContinuar?",
    ":INVOICE_ITEM_DETAILS": "${0} <br/> ${1} <br/> ${2}. <br/> Precio Estimado: $${3}. <br/> Identificaci\u00f3n del art\u00edculo de l\u00ednea: ${4} <br/> PO: ${5} <br/> Fecha de la orden: ${6}",
    ":INVOICE_CONFIRM_ITEM_DELETE": "\u00bfRemover este $${0} '${1}' cargo de la factura?",
    ":INVOICE_CONFIRM_ENTRY_DETACH": "\u00bfRemover $${0} cargo por el art\u00edculo ${1}, ${2} [${3}] de la factura?",
    ":LINEITEM_SUMMARY": "<div class='resumen-de-art\u00edculos-acq'><a href='${19}'>${0}</a>, por ${1} (${2})</div>\n<div class='resumen-de-art\u00edculos-acq-extra'>\n${3} Ordenados, ${4} Recibidos, ${7} Facturado, ${8} Reclamados, ${9} Cancelados</div>\n<div class='resumen-de-art\u00edculos-acq-extra'>Estimado $${6}, Sobrepasado $${16}, Pagado $${17}</div>\n<div class='resumen-de-art\u00edculos-acq-extra'>\n# ${10} <a style='padding-right: 10px;' class='hidden${20}' href='${11}/acq/po/view/${12}'>&#x2318; ${13} ${18}</a><a style='padding-right: 10px;' class='hidden${21}' href='${11}/acq/picklist/view/${14}'>&#x2756; ${15}</a></div>",
    ":INVOICE_CONFIRM_PRORATE": "\u00bfProrratear cambions?\n\nCualquier cambio subsiguiente a la factura que afectar\u00eda la cantidad prorrateada debe ser resuelta manualmente.",
    ":INVOICE_EXTRA_COPIES": "Esta intentando de hacer una factura <b>${0}</b> mas copias que originalmente ordenadas. <br/><br/> Para agregar estos art\u00edculos a su orden, seleccione un fondo y eliga 'Agregar Nuevos Art\u00edculos' debajo. <br/>Despu\u00e9s de guardar su factura, puede terminar de editar y importar las copias nuevas de la pagina de detalles en lineitem",
    ":INVOICE_ITEM_PO_DETAILS": "<b>${0}</b><br/><a target='_top' href='/eg2/en-US/staff/acq/po/${2}'>PO #${3} ${4}</a><br/>Total Estimated Cost: $${5}",
    ":INVOICE_ITEM_PO_LABEL": "<a target='_top' href='/eg2/en-US/staff/acq/po/${1}'>PO #${2} ${3}</a><br/>Total Estimated Cost: $${4}",
    ":UNNAMED": "Sin nombre",
    ":NO_FIND_INVOICE": "No se pudo encontrar la factura.",
    ":LI_BATCH_UPDATE": "actualizaci\u00f3n de posici\u00f3n de lote line",
    ":NO_LI_TO_UPDATE": "No ha seleccionado ning\u00fan art\u00edculo en l\u00ednea para actualizar .",
    ":NO_LI_TO_CLAIM": "Usted no ha seleccionado ning\u00fan \u00edtem para reclamar",
    ":NO_LID_TO_CLAIM": "usted no ha seleccionado ning\u00fan detalles de la l\u00ednea con la reivindicaci\u00f3n",
    ":CHANGE_CLAIM_POLICY": "Cambiar la forma de petici\u00f3n",
    ":CANCELED": "Cancelado",
    ":RECVD": "Recibido",
    ":NOT_RECVD": "No fue recibido",
    ":PRINT": "Imprimir",
    ":INVOICES": "Facturas",
    ":NUM_CLAIMS_EXISTING": "Reclamaciones (${0} existentes)",
    ":LOAD_TERMS_FIRST": "No puede recuperar registros hasta que alla cargado un archivo CSV\ncon identificaci\u00f3n bibliogr\u00e1fico en la primera columna.",
    ":SELECT_SEARCH_FIELD": "Eliga Campo de Busqueda",
    ":LIBRARY_INITIATED": "Librer\u00eda Iniciada",
    ":DEL_LI_FROM_PO": "Ya se orden\u00f3 el \u00edtem seleccionado! El borrarlo ahora no cancelar\u00e1 ni modificar\u00e1 cualquier pedido que haya sido realizado a un proveedor. El borrar el \u00edtem puede provocar una idea incorrecta del estado de la orden de compra en el sistema lo que es una inconsistencia con la realidad. Est\u00e1 seguro que quiere realizar esto?",
    ":ADD_LI_TO_PO_BAD_PO_STATE": "La OC seleccionada ha sido previamente activada",
    ":ADD_LI_TO_PO_BAD_LI_STATE": "El \u00edtem seleccionado est\u00e1 en un estado que no permite ser a\u00f1adido a una orden de compra",
    ":INVOICE_NUMBER": "Factura #$(0)",
    ":COPIES_TO_RECEIVE": "Numero de copias a recibir: ",
    ":CREATE_PO_INVALID": "Una orden de compra debe tener una agencia solicitante y un proveedor.",
    ":INVOICE_COPY_COUNT_INFO": "Copias recibidas en esta factura: ${0} de ${1}.",
    ":INVOICE_IDENT_COLLIDE": "Ya existe una factura en el sistema con la combinaci\u00f3n ofrecida para'N\u00ba de factura' y 'Proveedor', lo cual no se permite",
    ":NEW_INVOICE": "Nueva factura",
    ":ACQ_SEARCH_CLASS_ABBR_jub": "Ll",
    ":ACQ_SEARCH_CLASS_ABBR_acqpl": "SL",
    ":ACQ_SEARCH_CLASS_ABBR_acqpo": "OC",
    ":ACQ_SEARCH_CLASS_ABBR_acqinv": "I",
    ":ACQ_SEARCH_CLASS_ABBR_acqlid": "LID",
    ":ACQ_SEARCH_CLASS_ABBR_acqlia": "LIA",
    ":NO_LI_GENERAL": "No ha seleccionado ning\u00fan art\u00edculo en l\u00ednea ( adecuado) .",
    ":DUPE_PO_NAME_MSG": "Este nombre ya est\u00e1 en uso por otro correo",
    ":DUPE_PO_NAME_LINK": "Ver PO",
    ":PO_NAME_OPTIONAL": "${0} (optional)",
    ":FINALIZE_PO": "Finalizar este correo general?\n\nEsto facilitara todos los cargos generales y marcara el correo como recibido.",
    ":LI_EXISTING_COPIES": "Hay ${ 0 } copias existentes para este registro bibliogr\u00e1fico en esta ubicaci\u00f3n",
    ":LI_CREATING_ASSETS": "Creando bib, numero de llamada, y copiar archivos...",
    ":PO_ACTIVATING": "Activando orden de compra...",
    ":ACTIVATE_LI_PROCESSED": "Articulos de linea procesado: ${0}",
    ":ACTIVATE_VQBR_PROCESSED": "Vandelay Registros Procesados: ${0}",
    ":ACTIVATE_BIBS_PROCESSED": "Archivos Bib Fusionado/Importado: ${0}",
    ":ACTIVATE_LID_PROCESSED": "ACQ Copias Procesadas: ${0}",
    ":ACTIVATE_DEBITS_ACCRUED_PROCESSED": "D\u00e9bitos Gravados: ${0}",
    ":ACTIVATE_COPIES_PROCESSED": "copias reales procesados: ${0}"
}
